@@ -73,13 +73,17 @@ CheckReporter <- R6::R6Class("CheckReporter",
 )
 
 summary_line <- function(n_fail, n_warn, n_skip, n_pass) {
+  colourise_if <- function(text, colour, cond) {
+    if (cond) colourise(text, colour) else text
+  }
+
   # Ordered from most important to least important
   paste0(
     "[ ",
-    colourise("FAIL", "failure"), " ", n_fail, " | ",
-    colourise("WARN", "warn"),    " ", n_warn, " | ",
-    colourise("SKIP", "skip"),    " ", n_skip, " | ",
-    colourise("PASS", "success"), " ", n_pass,
+    colourise_if("FAIL", "failure", n_fail > 0), " ", n_fail, " | ",
+    colourise_if("WARN", "warn", n_warn > 0),    " ", n_warn, " | ",
+    colourise_if("SKIP", "skip", n_skip > 0),    " ", n_skip, " | ",
+    colourise_if("PASS", "success", n_fail == 0), " ", n_pass,
     " ]"
   )
 }
