@@ -1,9 +1,9 @@
 #' Run all tests in a directory
 #'
-#' Execute code in the specified file, displaying results using a `reporter`.
-#' Use this function when you want to run a single file's worth of tests.
-#' You are responsible for ensuring that the functions to test are available
-#' in the global environment.
+#' This function is the low-level workhorse that powers [test_local()] and
+#' [test_package()]. Generally, you should not call this function directly.
+#' In particular, you are responsible for ensuring that the functions to test
+#' are available in the test `env` (e.g. via `load_package`).
 #'
 #' @section Special files:
 #' There are two types of `.R` file that have special behaviour:
@@ -12,7 +12,7 @@
 #'
 #' * Setup files start with `setup` and are executed before tests. If
 #'   clean up is needed after all tests have been run, you can use
-#'   `withr::defer(clean_up(), teardown_env())`. See `vignette("text-fixtures")`
+#'   `withr::defer(clean_up(), teardown_env())`. See `vignette("test-fixtures")`
 #'   for more details.
 #'
 #' There are two other types of special file that we no longer recommend using:
@@ -51,6 +51,7 @@
 #'   * "installed", uses [library()] to load an installed package.
 #'   * "source", uses [pkgload::load_all()] to a source package.
 #' @param wrap DEPRECATED
+#' @keywords internal
 #' @return A list (invisibly) containing data about the test results.
 #' @inheritParams with_reporter
 #' @inheritParams source_file
@@ -115,7 +116,6 @@ test_dir <- function(path,
 
 #' Run all tests in a single file
 #'
-#' A variant of [test_dir()] that only tests a single file within a directory.
 #' Helper, setup, and teardown files located in the same directory as the
 #' test will also be run.
 #'
@@ -227,7 +227,10 @@ test_files_setup_state <- function(test_dir, test_package, load_helpers, env, .e
 
   # Define testing environment
   local_test_directory(test_dir, test_package, .env = .env)
-  withr::local_options(list(topLevelEnvironment = env_parent(env)), .local_envir = .env)
+  withr::local_options(
+    topLevelEnvironment = env_parent(env),
+    .local_envir = .env
+  )
 
   # Load helpers, setup, and teardown (on exit)
   local_teardown_env(.env)
@@ -244,7 +247,7 @@ test_files_reporter <- function(reporter, .env = parent.frame()) {
   reporters <- list(
     find_reporter(reporter),
     lister, # track data
-    local_snapshotter(.env = .env) # for snapshots
+    local_snapshotter("_snaps", .env = .env) # for snapshots
   )
   list(
     multi = MultiReporter$new(reporters = compact(reporters)),
@@ -277,9 +280,9 @@ test_one_file <- function(path, env = test_env(), wrap = TRUE) {
 
 #' Run code after all test files
 #'
-#' This environment no purpose except as a handle for [withr::defer()]: use
-#' this environment when you want to run code until after all tests have been
-#' run. Typically, you'll use `withr::defer(cleanup(), teardown_env())`
+#' This environment has no purpose other than as a handle for [withr::defer()]:
+#' use it when you want to run code after all tests have been run.
+#' Typically, you'll use `withr::defer(cleanup(), teardown_env())`
 #' immediately after you've made a mess in a `setup-*.R` file.
 #'
 #' @export
